/**
 * ### Фабрика типов паблишеров.
 * <br>
 * <br>
 * Через этот объект осуществляется доступ к менеджерам паблишеров, через которые можно получить доступ к самим паблишерам
 *
 *
 * @group manager
 * @namespace Publishers
 */
function Publishers() {
    /**
     *  Вернет ссылку на провайдер менеджера паблишеров (Publishers.PublisherManager).
     *  <br/>
     *  <br/>
     * ```
     * // Пример работы с фабрикой менеджеров для паблишеров
     *
     * // некий тип, например lpGeneric
     * var type = new v2.model_type("lpGeneric");
     *
     * ps.pl.pm.get(type).then(function(_ref){
     *     var publisher_manager_provider = _ref.value();
     *     // теперь можно работать с провайдером менеджера паблишера
     * }, function(_err){
     *     console.log("произошла ошибка")
     * });
     * ```
     *
     *
     * Изначально описано несколько типов паблишеров:
     *  - __lpGeneric__ - произвольный паблишер, от него отнаследованы все остальные
     *  - __lpComponents__ - паблишер для поиска по компонентам
     *  - __lpDiscovery__ - паблишер для отображения результатов поиска дискавери
     *  - __lpMassAction__ - паблишер для массовых действий
     *
     * @public
     * @function get
     * @param {v2.model_type} type Адрес паблишера
     * @returns {tools.promise<Publishers.PublisherManager>}
     * @memberof Publishers
     */
    this.get = function (type) {

    };

    /**
     *
     * @public
     * @function kill
     * @param {v2.model_type} type
     * @param {v2.address} address
     * @returns {boolean}
     * @memberof Publishers
     */
    this.kill = function (type, address) {

    };

    /**
     *
     * @public
     * @function delete
     * @param {v2.address} address
     * @returns {boolean}
     * @memberof Publishers
     */
    this.delete = function (address) {

    };
}